pub struct CoordinationWorkspaceCounts {
pub open: usize,
pub ready: usize,
pub blocked: usize,
pub in_progress: usize,
pub deferred: usize,
pub closed: usize,
}Expand description
Workspace context counts shown next to hidden-claim diagnosis.
Fields
open: usizeready: usizeblocked: usizein_progress: usizedeferred: usizeclosed: usizeTrait Implementations
Sourceimpl Clone for CoordinationWorkspaceCounts
impl Clone for CoordinationWorkspaceCounts
Sourcefn clone(&self) -> CoordinationWorkspaceCounts
fn clone(&self) -> CoordinationWorkspaceCounts
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CoordinationWorkspaceCounts
impl Debug for CoordinationWorkspaceCounts
Sourceimpl Default for CoordinationWorkspaceCounts
impl Default for CoordinationWorkspaceCounts
Sourcefn default() -> CoordinationWorkspaceCounts
fn default() -> CoordinationWorkspaceCounts
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CoordinationWorkspaceCounts
impl<'de> Deserialize<'de> for CoordinationWorkspaceCounts
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CoordinationWorkspaceCounts
impl JsonSchema for CoordinationWorkspaceCounts
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CoordinationWorkspaceCounts
impl PartialEq for CoordinationWorkspaceCounts
Sourcefn eq(&self, other: &CoordinationWorkspaceCounts) -> bool
fn eq(&self, other: &CoordinationWorkspaceCounts) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for CoordinationWorkspaceCounts
impl StructuralPartialEq for CoordinationWorkspaceCounts