pub struct StaleIssue {
pub created_at: DateTime<Utc>,
pub id: String,
pub issue_type: IssueType,
pub priority: Priority,
pub status: Status,
pub title: String,
pub updated_at: DateTime<Utc>,
pub assignee: Option<String>,
}Expand description
Minimal issue output for stale command (bd parity). Contains only the fields that bd’s stale command outputs.
Fields
created_at: DateTime<Utc>id: Stringissue_type: IssueTypepriority: Prioritystatus: Statustitle: Stringupdated_at: DateTime<Utc>assignee: Option<String>Trait Implementations
Sourceimpl Clone for StaleIssue
impl Clone for StaleIssue
Sourcefn clone(&self) -> StaleIssue
fn clone(&self) -> StaleIssue
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StaleIssue
impl Debug for StaleIssue
Sourceimpl<'de> Deserialize<'de> for StaleIssue
impl<'de> Deserialize<'de> for StaleIssue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<Issue> for StaleIssue
impl From<Issue> for StaleIssue
Sourceimpl JsonSchema for StaleIssue
impl JsonSchema for StaleIssue
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StaleIssue
impl RefUnwindSafe for StaleIssue
impl Send for StaleIssue
impl Sync for StaleIssue
impl Unpin for StaleIssue
impl UnsafeUnpin for StaleIssue
impl UnwindSafe for StaleIssue